## Notes

This is a non-functional TwinCAT IOC.

The twincat-pytmc plugin provided by whatrecord, backed by pytmc and blark,
parses this project and can provide PLC source code information for EPICS
records.
